@@ -32,7 +32,7 @@ class EPUBTableStyleManager
 
 public:
   //! constructor
-  EPUBTableStyleManager() : m_cellContentNameMap(), m_rowContentNameMap(), m_columWitdhsStack()
+  EPUBTableStyleManager() : m_cellContentNameMap(), m_rowContentNameMap(), m_tableContentNameMap(), m_columnWidthsStack(), m_relColumnWidthsStack()
   {
   }
   //! destructor
@@ -40,13 +40,21 @@ public:
   {
   }
   //! open a table
-  void openTable(librevenge::RVNGPropertyListVector const &colList);
+  void openTable(librevenge::RVNGPropertyList const &propList);
   //! close a table
   void closeTable();
   //! returns the class name corresponding to a propertylist
   std::string getCellClass(librevenge::RVNGPropertyList const &pList);
+  //! returns the style string corresponding to a propertylist
+  std::string getCellStyle(librevenge::RVNGPropertyList const &pList);
   //! returns the class name corresponding to a propertylist
   std::string getRowClass(librevenge::RVNGPropertyList const &pList);
+  //! returns the style string corresponding to a propertylist
+  std::string getRowStyle(librevenge::RVNGPropertyList const &pList);
+  //! returns the class name corresponding to a propertylist
+  std::string getTableClass(librevenge::RVNGPropertyList const &pList);
+  //! returns the style string corresponding to a propertylist
+  std::string getTableStyle(librevenge::RVNGPropertyList const &pList);
   //! send the data to the sink
   void send(EPUBCSSSink &out);
 private:
@@ -54,14 +62,22 @@ private:
   void extractCellProperties(librevenge::RVNGPropertyList const &pList, EPUBCSSProperties &cssProps) const;
   //! convert a property list into a CSS property map
   void extractRowProperties(librevenge::RVNGPropertyList const &pList, EPUBCSSProperties &cssProps) const;
+  //! convert a property list into a CSS property map
+  void extractTableProperties(librevenge::RVNGPropertyList const &pList, EPUBCSSProperties &cssProps) const;
   //! try to return the col width
   bool getColumnsWidth(int i, int numSpanned, double &w) const;
+  //! try to return the relative col width
+  bool getRelColumnsWidth(int i, int numSpanned, double &w) const;
   //! a map cell content -> name
   ContentNameMap_t m_cellContentNameMap;
   //! a map row content -> name
   ContentNameMap_t m_rowContentNameMap;
+  //! a map table content -> name
+  ContentNameMap_t m_tableContentNameMap;
   //! a stack of column width (in inches )
-  std::vector<std::vector<double> > m_columWitdhsStack;
+  std::vector<std::vector<double> > m_columnWidthsStack;
+  //! a stack of relative column width (in percents )
+  std::vector<std::vector<double> > m_relColumnWidthsStack;
 
   EPUBTableStyleManager(EPUBTableStyleManager const &orig);
   EPUBTableStyleManager operator=(EPUBTableStyleManager const &orig);
